/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*             EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                      TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                             **** MATEMTICAS ****
/*
/*                      Ciclo escolar evaluado: 2011 - 2012
/*_____________________________________________________________________________
/*
/*
/*            SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE
/*                         MATEMTICAS EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2012_Alum_Mat.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2012_Alum_Mat.txt
/*         as como el archivo Excale09_2012_Alum_Mat.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2012_Alum_Mat.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2012_Alum_Mat.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 18 DE MARZO DEL 2014
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale09_2012_Alum_Mat.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $entestF    "999999"  ="Respuesta omitida";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadCF      1         ="14 aos o menos"
                       2         ="15 aos"
                       3         ="16 aos"
                       4         ="17 aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadNF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edadAF      0         ="Sin edad anticipada"
                       1         ="Edad anticipada"
                       9         ="Respuesta omitida";
     VALUE edadEF      0         ="Sin extra edad severa"
                       1         ="Extra edad severa"
                       9         ="Respuesta omitida";
     VALUE reactF      0         ="Fallo"
                       1         ="Acierto"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Reactivo no administrado por error de impresin"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
     VALUE nvlF        1         ="Por debajo del nivel bsico"
                       2         ="Bsico"
                       3         ="Medio"
                       4         ="Avanzado";
     VALUE nvblF       0         ="Por debajo del nivel bsico"
                       1         ="Al menos el nivel bsico";
     VALUE nvmlF       0         ="Por debajo del nivel medio"
                       1         ="Al menos el nivel medio";
RUN;



DATA INEE.Excale09_2012_Alum_Mat;
   LENGTH
       NACIONAL         3
       ESCUELA          4
       ID_ENT           3
       NOM_ENT          $19
       ID_MOD           3
       MOD              $4
       ESTRATO          $6
       ENTEST           $6
       ALUMNO           5
       ID_INSTR         $15
       SEXO             3
       EDAD_AC          3
       MES_NAC          3
       EDAD             8
       EDAD_ACC         3
       EDAD_N           3
       EDAD_ANT         3
       EDAD_EES         3
       W_ALU            8
       SMA_01           3
       SMA_02           3
       SMA_03           3
       SMA_04           3
       SMA_05           3
       SMA_06           3
       SMA_07           3
       SMA_08           3
       SMA_09           3
       SMA_10           3
       SMA_11           3
       SMA_12           3
       SMB_01           3
       SMB_02           3
       SMB_03           3
       SMB_04           3
       SMB_05           3
       SMB_06           3
       SMB_07           3
       SMB_08           3
       SMB_09           3
       SMB_10           3
       SMB_11           3
       SMB_12           3
       SMB_13           3
       SMC_01           3
       SMC_02           3
       SMC_03           3
       SMC_04           3
       SMC_05           3
       SMC_06           3
       SMC_07           3
       SMC_08           3
       SMC_09           3
       SMC_10           3
       SMC_11           3
       SMC_12           3
       SMD_01           3
       SMD_02           3
       SMD_03           3
       SMD_04           3
       SMD_05           3
       SMD_06           3
       SMD_07           3
       SMD_08           3
       SMD_09           3
       SMD_10           3
       SMD_11           3
       SMD_12           3
       SME_01           3
       SME_02           3
       SME_03           3
       SME_04           3
       SME_05           3
       SME_06           3
       SME_07           3
       SME_08           3
       SME_09           3
       SME_10           3
       SME_11           3
       SME_12           3
       SME_13           3
       SMF_01           3
       SMF_02           3
       SMF_03           3
       SMF_04           3
       SMF_05           3
       SMF_06           3
       SMF_07           3
       SMF_08           3
       SMF_09           3
       SMF_10           3
       SMF_11           3
       SMF_12           3
       SMF_13           3
       SMG_01           3
       SMG_02           3
       SMG_03           3
       SMG_04           3
       SMG_05           3
       SMG_06           3
       SMG_07           3
       SMG_08           3
       SMG_09           3
       SMG_10           3
       SMG_11           3
       SMG_12           3
       SMH_01           3
       SMH_02           3
       SMH_03           3
       SMH_04           3
       SMH_05           3
       SMH_06           3
       SMH_07           3
       SMH_08           3
       SMH_09           3
       SMH_10           3
       SMH_11           3
       SMH_12           3
       SMH_13           3
       PV1MAT           8
       PV2MAT           8
       PV3MAT           8
       PV4MAT           8
       PV5MAT           8
       MATNVL1          3
       MATNVL2          3
       MATNVL3          3
       MATNVL4          3
       MATNVL5          3
       MATNVBL1         3
       MATNVBL2         3
       MATNVBL3         3
       MATNVBL4         3
       MATNVBL5         3
       MATNVML1         3
       MATNVML2         3
       MATNVML3         3
       MATNVML4         3
       MATNVML5         3
       WVARSTRR         3
       W_FSTR1          8
       W_FSTR2          8
       W_FSTR3          8
       W_FSTR4          8
       W_FSTR5          8
       W_FSTR6          8
       W_FSTR7          8
       W_FSTR8          8
       W_FSTR9          8
       W_FSTR10         8
       W_FSTR11         8
       W_FSTR12         8
       W_FSTR13         8
       W_FSTR14         8
       W_FSTR15         8
       W_FSTR16         8
       W_FSTR17         8
       W_FSTR18         8
       W_FSTR19         8
       W_FSTR20         8
       W_FSTR21         8
       W_FSTR22         8
       W_FSTR23         8
       W_FSTR24         8
       W_FSTR25         8
       W_FSTR26         8
       W_FSTR27         8
       W_FSTR28         8
       W_FSTR29         8
       W_FSTR30         8
       W_FSTR31         8
       W_FSTR32         8
       W_FSTR33         8
       W_FSTR34         8
       W_FSTR35         8
       W_FSTR36         8
       W_FSTR37         8
       W_FSTR38         8
       W_FSTR39         8
       W_FSTR40         8
       W_FSTR41         8
       W_FSTR42         8
       W_FSTR43         8
       W_FSTR44         8
       W_FSTR45         8
       W_FSTR46         8
       W_FSTR47         8
       W_FSTR48         8
       W_FSTR49         8
       W_FSTR50         8
       W_FSTR51         8
       W_FSTR52         8
       W_FSTR53         8
       W_FSTR54         8
       W_FSTR55         8
       W_FSTR56         8
       W_FSTR57         8
       W_FSTR58         8
       W_FSTR59         8
       W_FSTR60         8
       W_FSTR61         8
       W_FSTR62         8
       W_FSTR63         8
       W_FSTR64         8
       W_FSTR65         8
       W_FSTR66         8
       W_FSTR67         8
       W_FSTR68         8
       W_FSTR69         8
       W_FSTR70         8
       W_FSTR71         8
       W_FSTR72         8
       W_FSTR73         8
       W_FSTR74         8
       W_FSTR75         8
       W_FSTR76         8
       W_FSTR77         8
       W_FSTR78         8
       W_FSTR79         8
       W_FSTR80         8
       W_FSTR81         8
       W_FSTR82         8
       W_FSTR83         8
       W_FSTR84         8
       W_FSTR85         8
       W_FSTR86         8
       W_FSTR87         8
       W_FSTR88         8
       W_FSTR89         8
       W_FSTR90         8
       W_FSTR91         8
       W_FSTR92         8
       W_FSTR93         8
       W_FSTR94         8
       W_FSTR95         8
       W_FSTR96         8
       W_FSTR97         8
       W_FSTR98         8
       W_FSTR99         8
       W_FSTR100        8

 ;



INFILE alum MISSOVER LINESIZE = 1352;
   INPUT
      NACIONAL           1 - 1
      ESCUELA            2 - 5
      ID_ENT             6 - 7
      NOM_ENT            8 - 26
      ID_MOD            27 - 27
      MOD               28 - 31
      ESTRATO           32 - 37
      ENTEST            38 - 43
      ALUMNO            44 - 48
      ID_INSTR          49 - 63
      SEXO              64 - 64
      EDAD_AC           65 - 66
      MES_NAC           67 - 68
      EDAD              69 - 79
      EDAD_ACC          80 - 80
      EDAD_N            81 - 81
      EDAD_ANT          82 - 82
      EDAD_EES          83 - 83
      W_ALU             84 - 94
      SMA_01            95 - 95
      SMA_02            96 - 96
      SMA_03            97 - 97
      SMA_04            98 - 98
      SMA_05            99 - 99
      SMA_06           100 - 100
      SMA_07           101 - 101
      SMA_08           102 - 102
      SMA_09           103 - 103
      SMA_10           104 - 104
      SMA_11           105 - 105
      SMA_12           106 - 106
      SMB_01           107 - 107
      SMB_02           108 - 108
      SMB_03           109 - 109
      SMB_04           110 - 110
      SMB_05           111 - 111
      SMB_06           112 - 112
      SMB_07           113 - 113
      SMB_08           114 - 114
      SMB_09           115 - 115
      SMB_10           116 - 116
      SMB_11           117 - 117
      SMB_12           118 - 118
      SMB_13           119 - 119
      SMC_01           120 - 120
      SMC_02           121 - 121
      SMC_03           122 - 122
      SMC_04           123 - 123
      SMC_05           124 - 124
      SMC_06           125 - 125
      SMC_07           126 - 126
      SMC_08           127 - 127
      SMC_09           128 - 128
      SMC_10           129 - 129
      SMC_11           130 - 130
      SMC_12           131 - 131
      SMD_01           132 - 132
      SMD_02           133 - 133
      SMD_03           134 - 134
      SMD_04           135 - 135
      SMD_05           136 - 136
      SMD_06           137 - 137
      SMD_07           138 - 138
      SMD_08           139 - 139
      SMD_09           140 - 140
      SMD_10           141 - 141
      SMD_11           142 - 142
      SMD_12           143 - 143
      SME_01           144 - 144
      SME_02           145 - 145
      SME_03           146 - 146
      SME_04           147 - 147
      SME_05           148 - 148
      SME_06           149 - 149
      SME_07           150 - 150
      SME_08           151 - 151
      SME_09           152 - 152
      SME_10           153 - 153
      SME_11           154 - 154
      SME_12           155 - 155
      SME_13           156 - 156
      SMF_01           157 - 157
      SMF_02           158 - 158
      SMF_03           159 - 159
      SMF_04           160 - 160
      SMF_05           161 - 161
      SMF_06           162 - 162
      SMF_07           163 - 163
      SMF_08           164 - 164
      SMF_09           165 - 165
      SMF_10           166 - 166
      SMF_11           167 - 167
      SMF_12           168 - 168
      SMF_13           169 - 169
      SMG_01           170 - 170
      SMG_02           171 - 171
      SMG_03           172 - 172
      SMG_04           173 - 173
      SMG_05           174 - 174
      SMG_06           175 - 175
      SMG_07           176 - 176
      SMG_08           177 - 177
      SMG_09           178 - 178
      SMG_10           179 - 179
      SMG_11           180 - 180
      SMG_12           181 - 181
      SMH_01           182 - 182
      SMH_02           183 - 183
      SMH_03           184 - 184
      SMH_04           185 - 185
      SMH_05           186 - 186
      SMH_06           187 - 187
      SMH_07           188 - 188
      SMH_08           189 - 189
      SMH_09           190 - 190
      SMH_10           191 - 191
      SMH_11           192 - 192
      SMH_12           193 - 193
      SMH_13           194 - 194
      PV1MAT           195 - 202
      PV2MAT           203 - 210
      PV3MAT           211 - 218
      PV4MAT           219 - 226
      PV5MAT           227 - 234
      MATNVL1          235 - 235
      MATNVL2          236 - 236
      MATNVL3          237 - 237
      MATNVL4          238 - 238
      MATNVL5          239 - 239
      MATNVBL1         240 - 240
      MATNVBL2         241 - 241
      MATNVBL3         242 - 242
      MATNVBL4         243 - 243
      MATNVBL5         244 - 244
      MATNVML1         245 - 245
      MATNVML2         246 - 246
      MATNVML3         247 - 247
      MATNVML4         248 - 248
      MATNVML5         249 - 249
      WVARSTRR         250 - 252
      W_FSTR1          253 - 263
      W_FSTR2          264 - 274
      W_FSTR3          275 - 285
      W_FSTR4          286 - 296
      W_FSTR5          297 - 307
      W_FSTR6          308 - 318
      W_FSTR7          319 - 329
      W_FSTR8          330 - 340
      W_FSTR9          341 - 351
      W_FSTR10         352 - 362
      W_FSTR11         363 - 373
      W_FSTR12         374 - 384
      W_FSTR13         385 - 395
      W_FSTR14         396 - 406
      W_FSTR15         407 - 417
      W_FSTR16         418 - 428
      W_FSTR17         429 - 439
      W_FSTR18         440 - 450
      W_FSTR19         451 - 461
      W_FSTR20         462 - 472
      W_FSTR21         473 - 483
      W_FSTR22         484 - 494
      W_FSTR23         495 - 505
      W_FSTR24         506 - 516
      W_FSTR25         517 - 527
      W_FSTR26         528 - 538
      W_FSTR27         539 - 549
      W_FSTR28         550 - 560
      W_FSTR29         561 - 571
      W_FSTR30         572 - 582
      W_FSTR31         583 - 593
      W_FSTR32         594 - 604
      W_FSTR33         605 - 615
      W_FSTR34         616 - 626
      W_FSTR35         627 - 637
      W_FSTR36         638 - 648
      W_FSTR37         649 - 659
      W_FSTR38         660 - 670
      W_FSTR39         671 - 681
      W_FSTR40         682 - 692
      W_FSTR41         693 - 703
      W_FSTR42         704 - 714
      W_FSTR43         715 - 725
      W_FSTR44         726 - 736
      W_FSTR45         737 - 747
      W_FSTR46         748 - 758
      W_FSTR47         759 - 769
      W_FSTR48         770 - 780
      W_FSTR49         781 - 791
      W_FSTR50         792 - 802
      W_FSTR51         803 - 813
      W_FSTR52         814 - 824
      W_FSTR53         825 - 835
      W_FSTR54         836 - 846
      W_FSTR55         847 - 857
      W_FSTR56         858 - 868
      W_FSTR57         869 - 879
      W_FSTR58         880 - 890
      W_FSTR59         891 - 901
      W_FSTR60         902 - 912
      W_FSTR61         913 - 923
      W_FSTR62         924 - 934
      W_FSTR63         935 - 945
      W_FSTR64         946 - 956
      W_FSTR65         957 - 967
      W_FSTR66         968 - 978
      W_FSTR67         979 - 989
      W_FSTR68         990 - 1000
      W_FSTR69        1001 - 1011
      W_FSTR70        1012 - 1022
      W_FSTR71        1023 - 1033
      W_FSTR72        1034 - 1044
      W_FSTR73        1045 - 1055
      W_FSTR74        1056 - 1066
      W_FSTR75        1067 - 1077
      W_FSTR76        1078 - 1088
      W_FSTR77        1089 - 1099
      W_FSTR78        1100 - 1110
      W_FSTR79        1111 - 1121
      W_FSTR80        1122 - 1132
      W_FSTR81        1133 - 1143
      W_FSTR82        1144 - 1154
      W_FSTR83        1155 - 1165
      W_FSTR84        1166 - 1176
      W_FSTR85        1177 - 1187
      W_FSTR86        1188 - 1198
      W_FSTR87        1199 - 1209
      W_FSTR88        1210 - 1220
      W_FSTR89        1221 - 1231
      W_FSTR90        1232 - 1242
      W_FSTR91        1243 - 1253
      W_FSTR92        1254 - 1264
      W_FSTR93        1265 - 1275
      W_FSTR94        1276 - 1286
      W_FSTR95        1287 - 1297
      W_FSTR96        1298 - 1308
      W_FSTR97        1309 - 1319
      W_FSTR98        1320 - 1330
      W_FSTR99        1331 - 1341
      W_FSTR100       1342 - 1352
;




   LABEL
      NACIONAL       = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA        = "Identificador de la escuela"
      ID_ENT         = "Entidad federativa (identificador numrico)"
      NOM_ENT        = "Entidad federativa"
      ID_MOD         = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD            = "Estrato escolar o Modalidad educativa"
      ESTRATO        = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
      ENTEST         = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
      ALUMNO         = "Identificador del alumno"
      ID_INSTR       = "Identificador del cuadernillo de examen"
      SEXO           = "Sexo del alumno"
      EDAD_AC        = "Edad en aos cumplidos (al momento de la aplicacin)"
      MES_NAC        = "Mes de nacimiento del alumno"
      EDAD           = "Edad del alumno al mes de mayo de 2012, en aos (al momento de la aplicacin). Incluye los meses cumplidos (decimales)"
      EDAD_ACC       = "Edad en aos cumplidos codificada (con recodificacin y colapsamiento de categoras de la variable EDAD_AC)"
      EDAD_N         = "Edad normativa. Supone el ingreso al primero de primaria con 6 aos cumplidos (o menos) al primero de septiembre"
      EDAD_ANT       = "Edad anticipada. Variable indicadora de los alumnos que ingresaron al primero de primaria con menos de 6 aos cumplidos al primero de septiembre"
      EDAD_EES       = "Extra edad severa. Variable indicadora de los alumnos que tienen dos aos o ms de retraso en el sistema escolar"
      W_ALU          = "Peso muestral o ponderador del alumno"
      SMA_01         = "Identificar la factorizacin de un trinomio cuadrado perfecto y su justificacin."
      SMA_02         = "Identificar la representacin grfica, dada la expresin algebraica."
      SMA_03         = "Reconocer la figura que cubre una porcin de un plano."
      SMA_04         = "Identificar el valor de un ngulo en un tringulo a partir de la medida de los ngulos interiores."
      SMA_05         = "Sumar y restar nmeros fraccionarios."
      SMA_06         = "Identificar la variacin del radio al realizar cortes horizontales a un cono."
      SMA_07         = "Calcular el volumen de un cono."
      SMA_08         = "Identificar la grfica de una relacin de proporcionalidad directa."
      SMA_09         = "Identificar el evento que tiene mayor probabilidad de ganar."
      SMA_10         = "Identificar la grfica de un fenmeno dado."
      SMA_11         = "Identificar la mediana de un conjunto de datos impar."
      SMA_12         = "Identificar la expresin algebraica de la funcin lineal de una situacin dada."
      SMB_01         = "Sumar dos nmeros con signo distintos."
      SMB_02         = "Identificar el resultado de multiplicar y dividir nmeros con signo."
      SMB_03         = "Identificar el resultado de multiplicar y dividir nmeros naturales con exponentes positivos."
      SMB_04         = "Identificar la solucin de una ecuacin cuadrtica de la forma ax2 + bx + c = 0"
      SMB_05         = "Identificar la ecuacin de la forma x + a = b que modela una situacin dada."
      SMB_06         = "Calcular el valor de la hipotenusa en un tringulo rectngulo."
      SMB_07         = "Identificar el valor de un ngulo entre dos rectas que se cortan."
      SMB_08         = "Resolver problemas a partir de la mediatriz en un tringulo."
      SMB_09         = "Identificar el desarrollo plano de un cubo."
      SMB_10         = "Identificar una aplicacin del teorema de Tales."
      SMB_11         = "Identificar la grfica de una funcin lineal que muestra la razn de cambio de una situacin dada."
      SMB_12         = "Calcular la media de datos agrupados en una tabla."
      SMB_13         = "Calcular la probabilidad de un evento simple."
      SMC_01         = "Identificar el producto de dos binomios con un trmino en comn y su justificacin."
      SMC_02         = "Resolver problemas de multiplicacin de nmeros fraccionarios."
      SMC_03         = "Resolver problemas de divisin de nmeros fraccionarios."
      SMC_04         = "Resolver un problema de proporcionalidad mltiple."
      SMC_05         = "Identificar la ecuacin de la forma ax + bx + c = dx + ex + f  que permite calcular el permetro de un rectngulo."
      SMC_06         = "Identificar el resultado de una cadena de operaciones."
      SMC_07         = "Identificar el factor de proporcionalidad inverso dada la relacin de proporcionalidad."
      SMC_08         = "Identificar el diagrama de rbol de un problema de conteo."
      SMC_09         = "Identificar  informacin en un polgono de frecuencia."
      SMC_10         = "Identificar el comportamiento de la pendiente en un conjunto de rectas."
      SMC_11         = "Identificar la representacin  grfica formada de segmentos de recta de un fenmeno."
      SMC_12         = "Identificar la grfica que representa la solucin de un sistema de ecuaciones lineales."
      SMD_01         = "Identificar el procedimiento correcto para resolver un sistema de ecuaciones 2 x 2."
      SMD_02         = "Identificar el tipo de transformacin que se le aplica a una figura."
      SMD_03         = "Identificar las medidas posibles para la existencia y unicidad de generar un tringulo."
      SMD_04         = "Resolver problemas de conversin de kilmetros cuadrados a hectreas."
      SMD_05         = "Identificar el valor de un ngulo inscrito en una circunferencia dado el ngulo central."
      SMD_06         = "Resolver problemas que implican calcular el rea de un trapecio."
      SMD_07         = "Calcular el rea de un sector circular."
      SMD_08         = "Identificar la variacin del volumen de dos cilindros con el mismo radio pero diferente altura."
      SMD_09         = "Identificar figuras simtricas respecto a un eje."
      SMD_10         = "Resolver un problema que implica el producto de nmeros decimales hasta centsimos."
      SMD_11         = "Identificar el comportamiento de un conjunto de rectas cuando el valor de la ordenada aumenta o disminuye."
      SMD_12         = "Identificar la relacin entre una situacin dada y su expresin algebraica."
      SME_01         = "Identificar el procedimiento para resolver una ecuacin de la forma a(x + b) = d(x + e)"
      SME_02         = "Identificar la expresin equivalente a un nmero natural de una potencia negativa."
      SME_03         = "Identificar la ecuacin cuadrtica que modela una situacin dada."
      SME_04         = "Calcular el radio de un crculo dado el permetro."
      SME_05         = "Identificar la vista lateral de un cuerpo geomtrico formado por cubos."
      SME_06         = "Identificar la medida de un ngulo ubicado entre dos paralelas cortadas por una transversal."
      SME_07         = "Identificar el cuerpo geomtrico que se genera al rotar una figura sobre un eje horizontal."
      SME_08         = "Identificar la expresin trigonomtrica que permite calcular la hipotenusa dado el cateto y el ngulo adyacente."
      SME_09         = "Resolver un problema de conteo por medio de multiplicacin."
      SME_10         = "Resolver problemas de comparacin de razones."
      SME_11         = "Interpretar la informacin representada en una grfica circular."
      SME_12         = "Interpretar la informacin dada en una  grfica de lnea."
      SME_13         = "Interpretar la informacin dada en una grfica caja-brazos."
      SMF_01         = "Identificar nmeros decimales en la recta numrica."
      SMF_02         = "Traducir una frmula geomtrica al lenguaje natural."
      SMF_03         = "Resolver problemas que impliquen un sistema de ecuaciones 2 x 2."
      SMF_04         = "Identificar nmeros fraccionarios en la recta numrica."
      SMF_05         = "Identificar el sistema de ecuaciones que resuelve un problema dado."
      SMF_06         = "Calcular la suma de los ngulos interiores de un polgono."
      SMF_07         = "Resolver problemas de conversin de litros a centmetros cbicos."
      SMF_08         = "Calcular el rea sombreada que se genera en un crculo inscrito en un cuadrado."
      SMF_09         = "Identificar el valor faltante en una tabla de datos con un operador entero."
      SMF_10         = "Identificar el desarrollo plano de un cilindro."
      SMF_11         = "Identificar experimentos aleatorios equivalentes."
      SMF_12         = "Interpretar informacin en tablas de frecuencia absoluta y relativa."
      SMF_13         = "Identificar la grfica que representa un fenmeno con crecimiento geomtrico."
      SMG_01         = "Resolver problemas que implican el uso de nmeros naturales con signo."
      SMG_02         = "Resolver problemas de suma con nmeros decimales y fraccionarios."
      SMG_03         = "Identificar las expresiones algebraicas equivalentes dado un modelo geomtrico."
      SMG_04         = "Resolver problemas de divisin con nmeros decimales hasta centsimas."
      SMG_05         = "Identificar el valor del trmino que ocupa un determinado lugar en una sucesin dada."
      SMG_06         = "Calcular el valor del ancho de la base de un prisma rectangular dados el volumen, altura y largo de la base."
      SMG_07         = "Identificar el aumento del volumen de un cubo al variar la longitud de la arista."
      SMG_08         = "Calcular el valor de un trmino dado en una sucesin de figuras."
      SMG_09         = "Clcular la sexta potencia de un nmero decimal con exponente natural."
      SMG_10         = "Resolver problemas que implican sustraccin de binomios."
      SMG_11         = "Resolver problemas de valor faltante, con operador decimal."
      SMG_12         = "Identificar la tabla que muestra la relacin inversamente proporcional de un conjunto de datos."
      SMH_01         = "Resolver problemas de suma y resta con nmeros decimales."
      SMH_02         = "Resolver problemas en donde se emplea la notacin cientfica."
      SMH_03         = "Resolver problemas de multiplicacin de binomios."
      SMH_04         = "Resolver problemas de clculo de la raz cuadrada de nmeros naturales."
      SMH_05         = "Identificar el sistema de ecuaciones lineales 2 x2 que modela una situacin dada."
      SMH_06         = "Resolver problemas que implican calcular  porcentajes."
      SMH_07         = "Resolver problemas que implican el uso de  una ecuacin cuadrtica."
      SMH_08         = "Resolver problemas que implican el uso de las bisectrices en un tringulo rectngulo."
      SMH_09         = "Identificar la seccin que resulta al cortar un cono recto con un plano oblicuo."
      SMH_10         = "Resolver problemas que implican semejanza de  tringulos."
      SMH_11         = "Identificar cuntas circunferencias pueden construirse a partir del radio y dos puntos dados"
      SMH_12         = "Resolver problemas de reparto proporcional."
      SMH_13         = "Identificar la representacin grfica dados los datos en una tabla."
      PV1MAT         = "Primer valor plausible de Matemticas"
      PV2MAT         = "Segundo valor plausible de Matemticas"
      PV3MAT         = "Tercer valor plausible de Matemticas"
      PV4MAT         = "Cuarto valor plausible de Matemticas"
      PV5MAT         = "Quinto valor plausible de Matemticas"
      MATNVL1        = "Nivel de logro en Matemticas. Asociado a PV1MAT. (Cuatro niveles)"
      MATNVL2        = "Nivel de logro en Matemticas. Asociado a PV2MAT. (Cuatro niveles)"
      MATNVL3        = "Nivel de logro en Matemticas. Asociado a PV3MAT. (Cuatro niveles)"
      MATNVL4        = "Nivel de logro en Matemticas. Asociado a PV4MAT. (Cuatro niveles)"
      MATNVL5        = "Nivel de logro en Matemticas. Asociado a PV5MAT. (Cuatro niveles)"
      MATNVBL1       = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV1MAT."
      MATNVBL2       = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV2MAT."
      MATNVBL3       = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV3MAT."
      MATNVBL4       = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV4MAT."
      MATNVBL5       = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV5MAT."
      MATNVML1       = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV1MAT."
      MATNVML2       = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV2MAT."
      MATNVML3       = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV3MAT."
      MATNVML4       = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV4MAT."
      MATNVML5       = "Identifica si el alumno pertenece al menos al nivel medio de logro en Matemticas. Asociado a PV5MAT."
      WVARSTRR       = "Identificador del pseudoestrato (1 a 100) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR81       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR82       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR83       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR84       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR85       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR86       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR87       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR88       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR89       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR90       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR91       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR92       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR93       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR94       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR95       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR96       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR97       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR98       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR99       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR100      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;






   FORMAT
       NACIONAL          1.
       ESCUELA           4.
       ID_ENT            id_entF.
       NOM_ENT           $char19.
       ID_MOD            id_modF.
       MOD               $modF.
       ESTRATO           $char6.
       ENTEST            $entestF.
       ALUMNO            5.
       ID_INSTR          $char16.
       SEXO              sexoF.
       EDAD_AC           edad_acF.
       MES_NAC           mes_nacF.
       EDAD              edadF.
       EDAD_ACC          edadCF.
       EDAD_N            edadNF.
       EDAD_ANT          edadAF.
       EDAD_EES          edadEF.
       SMA_01            reactF.
       SMA_02            reactF.
       SMA_03            reactF.
       SMA_04            reactF.
       SMA_05            reactF.
       SMA_06            reactF.
       SMA_07            reactF.
       SMA_08            reactF.
       SMA_09            reactF.
       SMA_10            reactF.
       SMA_11            reactF.
       SMA_12            reactF.
       SMB_01            reactF.
       SMB_02            reactF.
       SMB_03            reactF.
       SMB_04            reactF.
       SMB_05            reactF.
       SMB_06            reactF.
       SMB_07            reactF.
       SMB_08            reactF.
       SMB_09            reactF.
       SMB_10            reactF.
       SMB_11            reactF.
       SMB_12            reactF.
       SMB_13            reactF.
       SMC_01            reactF.
       SMC_02            reactF.
       SMC_03            reactF.
       SMC_04            reactF.
       SMC_05            reactF.
       SMC_06            reactF.
       SMC_07            reactF.
       SMC_08            reactF.
       SMC_09            reactF.
       SMC_10            reactF.
       SMC_11            reactF.
       SMC_12            reactF.
       SMD_01            reactF.
       SMD_02            reactF.
       SMD_03            reactF.
       SMD_04            reactF.
       SMD_05            reactF.
       SMD_06            reactF.
       SMD_07            reactF.
       SMD_08            reactF.
       SMD_09            reactF.
       SMD_10            reactF.
       SMD_11            reactF.
       SMD_12            reactF.
       SME_01            reactF.
       SME_02            reactF.
       SME_03            reactF.
       SME_04            reactF.
       SME_05            reactF.
       SME_06            reactF.
       SME_07            reactF.
       SME_08            reactF.
       SME_09            reactF.
       SME_10            reactF.
       SME_11            reactF.
       SME_12            reactF.
       SME_13            reactF.
       SMF_01            reactF.
       SMF_02            reactF.
       SMF_03            reactF.
       SMF_04            reactF.
       SMF_05            reactF.
       SMF_06            reactF.
       SMF_07            reactF.
       SMF_08            reactF.
       SMF_09            reactF.
       SMF_10            reactF.
       SMF_11            reactF.
       SMF_12            reactF.
       SMF_13            reactF.
       SMG_01            reactF.
       SMG_02            reactF.
       SMG_03            reactF.
       SMG_04            reactF.
       SMG_05            reactF.
       SMG_06            reactF.
       SMG_07            reactF.
       SMG_08            reactF.
       SMG_09            reactF.
       SMG_10            reactF.
       SMG_11            reactF.
       SMG_12            reactF.
       SMH_01            reactF.
       SMH_02            reactF.
       SMH_03            reactF.
       SMH_04            reactF.
       SMH_05            reactF.
       SMH_06            reactF.
       SMH_07            reactF.
       SMH_08            reactF.
       SMH_09            reactF.
       SMH_10            reactF.
       SMH_11            reactF.
       SMH_12            reactF.
       SMH_13            reactF.
       MATNVL1           nvlF.
       MATNVL2           nvlF.
       MATNVL3           nvlF.
       MATNVL4           nvlF.
       MATNVL5           nvlF.
       MATNVBL1          nvblF.
       MATNVBL2          nvblF.
       MATNVBL3          nvblF.
       MATNVBL4          nvblF.
       MATNVBL5          nvblF.
       MATNVML1          nvmlF.
       MATNVML2          nvmlF.
       MATNVML3          nvmlF.
       MATNVML4          nvmlF.
       MATNVML5          nvmlF.
       wvarstrr          3.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;
   IF  entest = "999999" THEN  entest = .S;

   ARRAY perdidos1(5)  sexo edad_acc edad_n edad_ant edad_ant;
   DO  i=1 TO 5;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;


   ARRAY perdidos3(100)
                SMA_01 SMA_02 SMA_03 SMA_04 SMA_05 SMA_06 SMA_07 SMA_08 SMA_09 SMA_10
                SMA_11 SMA_12 SMB_01 SMB_02 SMB_03 SMB_04 SMB_05 SMB_06 SMB_07 SMB_08
                SMB_09 SMB_10 SMB_11 SMB_12 SMB_13 SMC_01 SMC_02 SMC_03 SMC_04 SMC_05
                SMC_06 SMC_07 SMC_08 SMC_09 SMC_10 SMC_11 SMC_12 SMD_01 SMD_02 SMD_03
                SMD_04 SMD_05 SMD_06 SMD_07 SMD_08 SMD_09 SMD_10 SMD_11 SMD_12 SME_01
                SME_02 SME_03 SME_04 SME_05 SME_06 SME_07 SME_08 SME_09 SME_10 SME_11
                SME_12 SME_13 SMF_01 SMF_02 SMF_03 SMF_04 SMF_05 SMF_06 SMF_07 SMF_08
                SMF_09 SMF_10 SMF_11 SMF_12 SMF_13 SMG_01 SMG_02 SMG_03 SMG_04 SMG_05
                SMG_06 SMG_07 SMG_08 SMG_09 SMG_10 SMG_11 SMG_12 SMH_01 SMH_02 SMH_03
                SMH_04 SMH_05 SMH_06 SMH_07 SMH_08 SMH_09 SMH_10 SMH_11 SMH_12 SMH_13;
   DO  i=1 TO 100;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
